Imperial Logic: Volume 2 - Mountain Culture Beer Co. - Untappd
Author: The Untappd Team
Description: Imperial Logic: Volume 2 by Mountain Culture Beer Co. is a Stout - Imperial / Double Pastry which has a rating of 4.3 out of 5, with 275 ratings and reviews on Untappd.
Keywords: Imperial Logic: Volume 2, Mountain Culture Beer Co., Stout - Imperial / Double Pastry, Australia, New South Wales

# Imperial Logic: Volume 2

Mountain Culture Beer Co.

Collaboration with Bottle Logic Brewing

Stout - Imperial / Double Pastry

Check-in Add

Total (?) 320

Unique (?) 287

Monthly (?) 2

You 0

10.5% ABV

N/A IBU

(4.26)

275 Ratings

Add Check-in
When we released our first collaboration with Bottle Logic in 2023, we exclaimed tha Show More
When we released our first collaboration with Bottle Logic in 2023, we exclaimed that it was our thickest, creamiest and sweetest stout to date.
That was true.
Until now.
Once again, we called on Wes and Stephen and together we worked on a recipe that would raise the bar.
For Version Two, we've added a whole pallet of pistachios (hand roasted by the brewers!), fresh vanilla bean and creme brulee to a rich, dark malt stout base for a luxuriously big, warming stout.
Contains Milk. Show Less

See All

Sort by: Global Friends You

### Global Recent Activity

Duff Man is drinking an Imperial Logic: Volume 2 by Mountain Culture Beer Co. at Duff Gardens

Purchased at Mountain Culture Beer Co.

Can

Tagged Friends
Fri, 21 Feb 2025 10:54:47 +0000 View Detailed Check-in
10

Anna is drinking an Imperial Logic: Volume 2 by Mountain Culture Beer Co. at Duff Gardens

Purchased at Mountain Culture Beer Co.

Can

Tagged Friends
Fri, 21 Feb 2025 10:47:11 +0000 View Detailed Check-in
7

Michael Boyer is drinking an Imperial Logic: Volume 2 by Mountain Culture Beer Co. at The Kelly Cottage

Viscosity and sugar content high. Pistachio, absent? Umami up front and taking a long time to find the sweet spot.

Can

Earned the Sky's the Limit (Level 48) badge!

Fri, 10 Jan 2025 03:17:34 +0000 View Detailed Check-in
3

Steve is drinking an Imperial Logic: Volume 2 by Mountain Culture Beer Co.

Can

Earned the Dark Desert: Stout - Imperial / Double Pastry badge! Earned the Beyond a Shadow of a Stout (Level 29) badge!
Sun, 05 Jan 2025 11:59:50 +0000 View Detailed Check-in
1

Kenneth Dinesen is drinking an Imperial Logic: Volume 2 by Mountain Culture Beer Co. at Barry's Brewhouse

Earned the Dessert Time! (Level 48) badge!
Tagged Friends
Mon, 23 Dec 2024 10:58:43 +0000 View Detailed Check-in
2

David Sansome is drinking an Imperial Logic: Volume 2 by Mountain Culture Beer Co. at Untappd at Home

Can

Tagged Friends
Mon, 23 Dec 2024 10:53:43 +0000 View Detailed Check-in
0

Mark Rippingale is drinking an Imperial Logic: Volume 2 by Mountain Culture Beer Co. at Untappd at Home

Rich and chocolatey.

Can

Earned the Dark Desert: Stout - Imperial / Double Pastry badge! Earned the Sky's the Limit (Level 48) badge! Earned the Better Together (Level 17) badge! Earned the Heavy Weight (Level 75) badge! Earned the Dessert Time! (Level 13) badge!

Sun, 22 Dec 2024 05:39:29 +0000 View Detailed Check-in
2

Damian P: Get a badge!

Sun, 22 Dec 2024 05:39:56 +0000 Report

Damian P is drinking an Imperial Logic: Volume 2 by Mountain Culture Beer Co. at Mark's Menagerie Of Mayhem

#ForTheBadge

Can

Earned the Dark Desert: Stout - Imperial / Double Pastry badge!
Tagged Friends

Sun, 22 Dec 2024 05:35:45 +0000 View Detailed Check-in
27

Pamela Gillespie: 🤜🤛

Sun, 22 Dec 2024 15:52:43 +0000 Report

Damian P: 🍺👍🏻😎😍🍻😉💸

Sun, 22 Dec 2024 21:13:48 +0000 Report

Matt TheMadGerman is drinking an Imperial Logic: Volume 2 by Mountain Culture Beer Co. at Untappd at Home

Vol. 1 was delicious and MC and Bottle Logic -what to expect except of tastiness! Rich, thick chocolate sweetness, balanced with caramel.Heavy but smooth,easy finish and no volatility.its creme brulee so some of the sourness unfortunately. (800th)

Can

Earned the For the Can (Level 34) badge! Earned the 2X (Level 35) badge!
Tagged Friends

Sat, 14 Dec 2024 14:19:23 +0000 View Detailed Check-in
1

Adam Kapamadjian: #Stout365 🍺🖤😋

Sat, 14 Dec 2024 21:42:58 +0000 Report

Anthony Willingham is drinking an Imperial Logic: Volume 2 by Mountain Culture Beer Co. at Untappd at Home

Purchased at Mountain Culture Beer Co.

Can

Earned the Better Together (Level 23) badge!
Tagged Friends

Fri, 13 Dec 2024 09:26:09 +0000 View Detailed Check-in
2

Jamie Maxfield is drinking an Imperial Logic: Volume 2 by Mountain Culture Beer Co.

Earned the Sky's the Limit (Level 13) badge! Earned the 2X (Level 31) badge!
Sat, 07 Dec 2024 22:34:56 +0000 View Detailed Check-in
0

Legless Always is drinking an Imperial Logic: Volume 2 by Mountain Culture Beer Co.

Can

Earned the Dessert Time! (Level 81) badge!

Sat, 07 Dec 2024 08:43:55 +0000 View Detailed Check-in
0

Damian Lazarevski is drinking an Imperial Logic: Volume 2 by Mountain Culture Beer Co. at Hopheads Yarraville

Earned the Better Together (Level 3) badge! Earned the 2X (Level 7) badge! Earned the Dessert Time! (Level 7) badge!
Sat, 07 Dec 2024 04:50:27 +0000 View Detailed Check-in
1

Kane La Pouple is drinking an Imperial Logic: Volume 2 by Mountain Culture Beer Co. at Hopheads Altona

Can

Earned the Sky's the Limit (Level 80) badge!

Sat, 07 Dec 2024 04:49:38 +0000 View Detailed Check-in
1

William Niven is drinking an Imperial Logic: Volume 2 by Mountain Culture Beer Co. at Untappd at Home

Can

Earned the Dessert Time! (Level 7) badge!
Fri, 06 Dec 2024 11:44:15 +0000 View Detailed Check-in
0

David Sansome is drinking an Imperial Logic: Volume 2 by Mountain Culture Beer Co. at Untappd at Home

Can

Tagged Friends
Fri, 29 Nov 2024 12:28:38 +0000 View Detailed Check-in
0

Docker Beerman is drinking an Imperial Logic: Volume 2 by Mountain Culture Beer Co. at Joel's Beertopia

LCI still think this keeps getting better, only 1 left (I think) will save for a rainy day next winter

Can

Thu, 21 Nov 2024 12:51:18 +0000 View Detailed Check-in
3

Pat Sollom is drinking an Imperial Logic: Volume 2 by Mountain Culture Beer Co. at Hahnenkamm Chalet

Purchased at Carwyn Cellars

Can

Mon, 18 Nov 2024 05:18:31 +0000 View Detailed Check-in
1

M D is drinking an Imperial Logic: Volume 2 by Mountain Culture Beer Co.

Fri, 01 Nov 2024 11:36:04 +0000 View Detailed Check-in
1

Cameron Baguley is drinking an Imperial Logic: Volume 2 by Mountain Culture Beer Co.

Sun, 27 Oct 2024 07:42:06 +0000 View Detailed Check-in
2
Show More